# tiledb-cloud
TileDB Storage Platform REST API

The `rest_api` package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 2.0.4
- Package version: 1.0.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage

This python library package is generated without supporting files like setup.py or requirements files

To be able to use it, you will need these dependencies in your own package that uses this library:

* urllib3 >= 1.15
* six >= 1.10
* certifi
* python-dateutil

## Getting Started

In your own code, to use this library to connect and interact with tiledb-cloud,
you can run the following:

```python
from __future__ import print_function
import time
import rest_api
from rest_api.rest import ApiException
from pprint import pprint

configuration = rest_api.Configuration()
# Configure API key authorization: ApiKeyAuth
configuration.api_key['X-TILEDB-REST-API-KEY'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['X-TILEDB-REST-API-KEY'] = 'Bearer'
configuration = rest_api.Configuration()
# Configure HTTP basic authorization: BasicAuth
configuration.username = 'YOUR_USERNAME'
configuration.password = 'YOUR_PASSWORD'

# Defining host is optional and default to http://localhost/v1
configuration.host = "http://localhost/v1"
# Create an instance of the API class
api_instance = rest_api.ArrayApi(rest_api.ApiClient(configuration))
namespace = 'namespace_example' # str | namespace array is in (an organization name or user's username)
array = 'array_example' # str | name/uri of array that is url-encoded
start = 56 # int | Start time of window of fetch logs, unix epoch in seconds (default: seven days ago) (optional)
end = 56 # int | End time of window of fetch logs, unix epoch in seconds (default: current utc timestamp) (optional)
event_types = 'event_types_example' # str | Event values can be one or more of the following read, write, create, delete, register, deregister, comma separated (optional)
task_id = 'task_id_example' # str | Array task id To filter activity to (optional)

try:
    api_response = api_instance.array_activity_log(namespace, array, start=start, end=end, event_types=event_types, task_id=task_id)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling ArrayApi->array_activity_log: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ArrayApi* | [**array_activity_log**](rest_api/docs/ArrayApi.md#array_activity_log) | **GET** /arrays/{namespace}/{array}/activity | 
*ArrayApi* | [**arrays_browser_owned_get**](rest_api/docs/ArrayApi.md#arrays_browser_owned_get) | **GET** /arrays/browser/owned | 
*ArrayApi* | [**arrays_browser_owned_sidebar_get**](rest_api/docs/ArrayApi.md#arrays_browser_owned_sidebar_get) | **GET** /arrays/browser/owned/sidebar | 
*ArrayApi* | [**arrays_browser_public_get**](rest_api/docs/ArrayApi.md#arrays_browser_public_get) | **GET** /arrays/browser/public | 
*ArrayApi* | [**arrays_browser_public_sidebar_get**](rest_api/docs/ArrayApi.md#arrays_browser_public_sidebar_get) | **GET** /arrays/browser/public/sidebar | 
*ArrayApi* | [**arrays_browser_shared_get**](rest_api/docs/ArrayApi.md#arrays_browser_shared_get) | **GET** /arrays/browser/shared | 
*ArrayApi* | [**arrays_browser_shared_sidebar_get**](rest_api/docs/ArrayApi.md#arrays_browser_shared_sidebar_get) | **GET** /arrays/browser/shared/sidebar | 
*ArrayApi* | [**create_array**](rest_api/docs/ArrayApi.md#create_array) | **POST** /arrays/{namespace}/{array} | 
*ArrayApi* | [**delete_array**](rest_api/docs/ArrayApi.md#delete_array) | **DELETE** /arrays/{namespace}/{array} | 
*ArrayApi* | [**deregister_array**](rest_api/docs/ArrayApi.md#deregister_array) | **DELETE** /arrays/{namespace}/{array}/deregister | 
*ArrayApi* | [**get_all_array_metadata**](rest_api/docs/ArrayApi.md#get_all_array_metadata) | **GET** /arrays | 
*ArrayApi* | [**get_array**](rest_api/docs/ArrayApi.md#get_array) | **GET** /arrays/{namespace}/{array} | 
*ArrayApi* | [**get_array_max_buffer_sizes**](rest_api/docs/ArrayApi.md#get_array_max_buffer_sizes) | **GET** /arrays/{namespace}/{array}/max_buffer_sizes | 
*ArrayApi* | [**get_array_meta_data_json**](rest_api/docs/ArrayApi.md#get_array_meta_data_json) | **GET** /arrays/{namespace}/{array}/metadata_json | 
*ArrayApi* | [**get_array_metadata**](rest_api/docs/ArrayApi.md#get_array_metadata) | **GET** /arrays/{namespace}/{array}/metadata | 
*ArrayApi* | [**get_array_non_empty_domain**](rest_api/docs/ArrayApi.md#get_array_non_empty_domain) | **GET** /arrays/{namespace}/{array}/non_empty_domain | 
*ArrayApi* | [**get_array_sample_data**](rest_api/docs/ArrayApi.md#get_array_sample_data) | **GET** /arrays/{namespace}/{array}/sample | 
*ArrayApi* | [**get_array_sharing_policies**](rest_api/docs/ArrayApi.md#get_array_sharing_policies) | **GET** /arrays/{namespace}/{array}/share | 
*ArrayApi* | [**get_arrays_in_namespace**](rest_api/docs/ArrayApi.md#get_arrays_in_namespace) | **GET** /arrays/{namespace} | 
*ArrayApi* | [**get_last_accessed_arrays**](rest_api/docs/ArrayApi.md#get_last_accessed_arrays) | **GET** /arrays/last_accessed | 
*ArrayApi* | [**register_array**](rest_api/docs/ArrayApi.md#register_array) | **POST** /arrays/{namespace}/{array}/register | 
*ArrayApi* | [**share_array**](rest_api/docs/ArrayApi.md#share_array) | **PATCH** /arrays/{namespace}/{array}/share | 
*ArrayApi* | [**update_array_metadata**](rest_api/docs/ArrayApi.md#update_array_metadata) | **PATCH** /arrays/{namespace}/{array}/metadata | 
*ArrayTasksApi* | [**get_array_tasks_sidebar**](rest_api/docs/ArrayTasksApi.md#get_array_tasks_sidebar) | **GET** /tasks/sidebar | 
*FavoritesApi* | [**delete_favorite_id**](rest_api/docs/FavoritesApi.md#delete_favorite_id) | **DELETE** /favorites/{id} | 
*FavoritesApi* | [**get_favorite**](rest_api/docs/FavoritesApi.md#get_favorite) | **GET** /favorites/{id} | 
*FavoritesApi* | [**get_favorites**](rest_api/docs/FavoritesApi.md#get_favorites) | **GET** /favorites | 
*FavoritesApi* | [**post_favorite**](rest_api/docs/FavoritesApi.md#post_favorite) | **POST** /favorites | 
*InvitationApi* | [**accept_invitation**](rest_api/docs/InvitationApi.md#accept_invitation) | **POST** /invitations/{invitation} | 
*InvitationApi* | [**cancel_join_organization**](rest_api/docs/InvitationApi.md#cancel_join_organization) | **DELETE** /invitations/{invitation}/{organization}/join | 
*InvitationApi* | [**cancel_share_array_by_invite**](rest_api/docs/InvitationApi.md#cancel_share_array_by_invite) | **DELETE** /invitations/{invitation}/{namespace}/{array}/share | 
*InvitationApi* | [**fetch_invitations**](rest_api/docs/InvitationApi.md#fetch_invitations) | **GET** /invitations | 
*InvitationApi* | [**join_organization**](rest_api/docs/InvitationApi.md#join_organization) | **POST** /invitations/{organization}/join | 
*InvitationApi* | [**share_array_by_invite**](rest_api/docs/InvitationApi.md#share_array_by_invite) | **POST** /invitations/{namespace}/{array}/share | 
*NotebookApi* | [**get_notebook_server_status**](rest_api/docs/NotebookApi.md#get_notebook_server_status) | **GET** /notebooks/server/{namespace}/status | 
*NotebookApi* | [**shutdown_notebook_server**](rest_api/docs/NotebookApi.md#shutdown_notebook_server) | **DELETE** /notebooks/server/{namespace} | 
*OrganizationApi* | [**add_aws_access_credentials**](rest_api/docs/OrganizationApi.md#add_aws_access_credentials) | **POST** /credentials/{namespace}/aws | 
*OrganizationApi* | [**add_user_to_organization**](rest_api/docs/OrganizationApi.md#add_user_to_organization) | **POST** /organizations/{organization}/user | 
*OrganizationApi* | [**check_aws_access_credentials**](rest_api/docs/OrganizationApi.md#check_aws_access_credentials) | **GET** /credentials/{namespace}/aws | 
*OrganizationApi* | [**check_aws_access_credentials_by_name**](rest_api/docs/OrganizationApi.md#check_aws_access_credentials_by_name) | **GET** /credentials/{namespace}/aws/{name} | 
*OrganizationApi* | [**create_organization**](rest_api/docs/OrganizationApi.md#create_organization) | **POST** /organization | 
*OrganizationApi* | [**delete_aws_access_credentials**](rest_api/docs/OrganizationApi.md#delete_aws_access_credentials) | **DELETE** /credentials/{namespace}/aws/{name} | 
*OrganizationApi* | [**delete_organization**](rest_api/docs/OrganizationApi.md#delete_organization) | **DELETE** /organizations/{organization} | 
*OrganizationApi* | [**delete_user_from_organization**](rest_api/docs/OrganizationApi.md#delete_user_from_organization) | **DELETE** /organizations/{organization}/{username} | 
*OrganizationApi* | [**get_all_organizations**](rest_api/docs/OrganizationApi.md#get_all_organizations) | **GET** /organizations | 
*OrganizationApi* | [**get_organization**](rest_api/docs/OrganizationApi.md#get_organization) | **GET** /organizations/{organization} | 
*OrganizationApi* | [**get_organization_user**](rest_api/docs/OrganizationApi.md#get_organization_user) | **GET** /organizations/{organization}/{username} | 
*OrganizationApi* | [**update_aws_access_credentials**](rest_api/docs/OrganizationApi.md#update_aws_access_credentials) | **PATCH** /credentials/{namespace}/aws/{name} | 
*OrganizationApi* | [**update_organization**](rest_api/docs/OrganizationApi.md#update_organization) | **PATCH** /organizations/{organization} | 
*OrganizationApi* | [**update_user_in_organization**](rest_api/docs/OrganizationApi.md#update_user_in_organization) | **PATCH** /organizations/{organization}/{username} | 
*QueryApi* | [**finalize_query**](rest_api/docs/QueryApi.md#finalize_query) | **POST** /arrays/{namespace}/{array}/query/finalize | 
*QueryApi* | [**get_est_result_sizes**](rest_api/docs/QueryApi.md#get_est_result_sizes) | **POST** /arrays/{namespace}/{array}/query/est_result_sizes | 
*QueryApi* | [**submit_query**](rest_api/docs/QueryApi.md#submit_query) | **POST** /arrays/{namespace}/{array}/query/submit | 
*SqlApi* | [**run_sql**](rest_api/docs/SqlApi.md#run_sql) | **POST** /sql/{namespace} | 
*StatsApi* | [**get_tiledb_stats**](rest_api/docs/StatsApi.md#get_tiledb_stats) | **GET** /.stats | 
*TasksApi* | [**run_sql**](rest_api/docs/TasksApi.md#run_sql) | **POST** /sql/{namespace} | 
*TasksApi* | [**task_id_get**](rest_api/docs/TasksApi.md#task_id_get) | **GET** /task/{id} | 
*TasksApi* | [**tasks_get**](rest_api/docs/TasksApi.md#tasks_get) | **GET** /tasks | 
*UdfApi* | [**get_udf_info**](rest_api/docs/UdfApi.md#get_udf_info) | **GET** /udf/{namespace}/{name} | 
*UdfApi* | [**get_udf_info_list**](rest_api/docs/UdfApi.md#get_udf_info_list) | **GET** /udfs | 
*UdfApi* | [**get_udf_info_sharing_policies**](rest_api/docs/UdfApi.md#get_udf_info_sharing_policies) | **GET** /udf/{namespace}/{name}/share | 
*UdfApi* | [**register_udf_info**](rest_api/docs/UdfApi.md#register_udf_info) | **POST** /udf/{namespace}/{name} | 
*UdfApi* | [**share_udf_info**](rest_api/docs/UdfApi.md#share_udf_info) | **PATCH** /udf/{namespace}/{name}/share | 
*UdfApi* | [**submit_generic_udf**](rest_api/docs/UdfApi.md#submit_generic_udf) | **POST** /udfs/generic/{namespace} | 
*UdfApi* | [**submit_udf**](rest_api/docs/UdfApi.md#submit_udf) | **POST** /arrays/{namespace}/{array}/udf/submit | 
*UdfApi* | [**update_udf_info**](rest_api/docs/UdfApi.md#update_udf_info) | **PATCH** /udf/{namespace}/{name} | 
*UserApi* | [**add_aws_access_credentials**](rest_api/docs/UserApi.md#add_aws_access_credentials) | **POST** /credentials/{namespace}/aws | 
*UserApi* | [**add_user_to_organization**](rest_api/docs/UserApi.md#add_user_to_organization) | **POST** /organizations/{organization}/user | 
*UserApi* | [**check_aws_access_credentials**](rest_api/docs/UserApi.md#check_aws_access_credentials) | **GET** /credentials/{namespace}/aws | 
*UserApi* | [**check_aws_access_credentials_by_name**](rest_api/docs/UserApi.md#check_aws_access_credentials_by_name) | **GET** /credentials/{namespace}/aws/{name} | 
*UserApi* | [**confirm_email**](rest_api/docs/UserApi.md#confirm_email) | **POST** /user/confirm_email | 
*UserApi* | [**create_user**](rest_api/docs/UserApi.md#create_user) | **POST** /user | 
*UserApi* | [**delete_aws_access_credentials**](rest_api/docs/UserApi.md#delete_aws_access_credentials) | **DELETE** /credentials/{namespace}/aws/{name} | 
*UserApi* | [**delete_user**](rest_api/docs/UserApi.md#delete_user) | **DELETE** /users/{username} | 
*UserApi* | [**delete_user_from_organization**](rest_api/docs/UserApi.md#delete_user_from_organization) | **DELETE** /organizations/{organization}/{username} | 
*UserApi* | [**get_organization_user**](rest_api/docs/UserApi.md#get_organization_user) | **GET** /organizations/{organization}/{username} | 
*UserApi* | [**get_session**](rest_api/docs/UserApi.md#get_session) | **GET** /session | 
*UserApi* | [**get_user**](rest_api/docs/UserApi.md#get_user) | **GET** /user | 
*UserApi* | [**get_user_with_username**](rest_api/docs/UserApi.md#get_user_with_username) | **GET** /users/{username} | 
*UserApi* | [**request_token**](rest_api/docs/UserApi.md#request_token) | **POST** /token | 
*UserApi* | [**reset_user_password**](rest_api/docs/UserApi.md#reset_user_password) | **POST** /user/password_reset | 
*UserApi* | [**revoke_token**](rest_api/docs/UserApi.md#revoke_token) | **DELETE** /tokens/{token} | 
*UserApi* | [**tokens_get**](rest_api/docs/UserApi.md#tokens_get) | **GET** /tokens | 
*UserApi* | [**update_aws_access_credentials**](rest_api/docs/UserApi.md#update_aws_access_credentials) | **PATCH** /credentials/{namespace}/aws/{name} | 
*UserApi* | [**update_user**](rest_api/docs/UserApi.md#update_user) | **PATCH** /users/{username} | 
*UserApi* | [**update_user_in_organization**](rest_api/docs/UserApi.md#update_user_in_organization) | **PATCH** /organizations/{organization}/{username} | 


## Documentation For Models

 - [AWSAccessCredentials](rest_api/docs/AWSAccessCredentials.md)
 - [ActivityEventType](rest_api/docs/ActivityEventType.md)
 - [Array](rest_api/docs/Array.md)
 - [ArrayActions](rest_api/docs/ArrayActions.md)
 - [ArrayActivityLog](rest_api/docs/ArrayActivityLog.md)
 - [ArrayBrowserData](rest_api/docs/ArrayBrowserData.md)
 - [ArrayBrowserSidebar](rest_api/docs/ArrayBrowserSidebar.md)
 - [ArrayInfo](rest_api/docs/ArrayInfo.md)
 - [ArrayInfoUpdate](rest_api/docs/ArrayInfoUpdate.md)
 - [ArrayMetadata](rest_api/docs/ArrayMetadata.md)
 - [ArrayMetadataEntry](rest_api/docs/ArrayMetadataEntry.md)
 - [ArraySample](rest_api/docs/ArraySample.md)
 - [ArraySchema](rest_api/docs/ArraySchema.md)
 - [ArraySharing](rest_api/docs/ArraySharing.md)
 - [ArrayTask](rest_api/docs/ArrayTask.md)
 - [ArrayTaskBrowserSidebar](rest_api/docs/ArrayTaskBrowserSidebar.md)
 - [ArrayTaskData](rest_api/docs/ArrayTaskData.md)
 - [ArrayTaskLog](rest_api/docs/ArrayTaskLog.md)
 - [ArrayTaskStatus](rest_api/docs/ArrayTaskStatus.md)
 - [ArrayTaskType](rest_api/docs/ArrayTaskType.md)
 - [ArrayType](rest_api/docs/ArrayType.md)
 - [Attribute](rest_api/docs/Attribute.md)
 - [AttributeBufferHeader](rest_api/docs/AttributeBufferHeader.md)
 - [AttributeBufferSize](rest_api/docs/AttributeBufferSize.md)
 - [Datatype](rest_api/docs/Datatype.md)
 - [Dimension](rest_api/docs/Dimension.md)
 - [DimensionCoordinate](rest_api/docs/DimensionCoordinate.md)
 - [DimensionTileExtent](rest_api/docs/DimensionTileExtent.md)
 - [Domain](rest_api/docs/Domain.md)
 - [DomainArray](rest_api/docs/DomainArray.md)
 - [Error](rest_api/docs/Error.md)
 - [Favorite](rest_api/docs/Favorite.md)
 - [FavoriteType](rest_api/docs/FavoriteType.md)
 - [FavoriteUpdate](rest_api/docs/FavoriteUpdate.md)
 - [Filter](rest_api/docs/Filter.md)
 - [FilterData](rest_api/docs/FilterData.md)
 - [FilterOption](rest_api/docs/FilterOption.md)
 - [FilterPipeline](rest_api/docs/FilterPipeline.md)
 - [FilterType](rest_api/docs/FilterType.md)
 - [GenericUDF](rest_api/docs/GenericUDF.md)
 - [InlineObject](rest_api/docs/InlineObject.md)
 - [InlineResponse200](rest_api/docs/InlineResponse200.md)
 - [Invitation](rest_api/docs/Invitation.md)
 - [InvitationArrayShareEmail](rest_api/docs/InvitationArrayShareEmail.md)
 - [InvitationData](rest_api/docs/InvitationData.md)
 - [InvitationOrganizationJoinEmail](rest_api/docs/InvitationOrganizationJoinEmail.md)
 - [InvitationStatus](rest_api/docs/InvitationStatus.md)
 - [InvitationType](rest_api/docs/InvitationType.md)
 - [LastAccessedArray](rest_api/docs/LastAccessedArray.md)
 - [Layout](rest_api/docs/Layout.md)
 - [MaxBufferSizes](rest_api/docs/MaxBufferSizes.md)
 - [NamespaceActions](rest_api/docs/NamespaceActions.md)
 - [NonEmptyDomain](rest_api/docs/NonEmptyDomain.md)
 - [NotebookSettings](rest_api/docs/NotebookSettings.md)
 - [NotebookStatus](rest_api/docs/NotebookStatus.md)
 - [Organization](rest_api/docs/Organization.md)
 - [OrganizationRoles](rest_api/docs/OrganizationRoles.md)
 - [OrganizationUser](rest_api/docs/OrganizationUser.md)
 - [PaginationMetadata](rest_api/docs/PaginationMetadata.md)
 - [Pricing](rest_api/docs/Pricing.md)
 - [PricingAggregateUsage](rest_api/docs/PricingAggregateUsage.md)
 - [PricingCurrency](rest_api/docs/PricingCurrency.md)
 - [PricingInterval](rest_api/docs/PricingInterval.md)
 - [PricingType](rest_api/docs/PricingType.md)
 - [PricingUnitLabel](rest_api/docs/PricingUnitLabel.md)
 - [PublicShareFilter](rest_api/docs/PublicShareFilter.md)
 - [Query](rest_api/docs/Query.md)
 - [QueryReader](rest_api/docs/QueryReader.md)
 - [Querystatus](rest_api/docs/Querystatus.md)
 - [Querytype](rest_api/docs/Querytype.md)
 - [ReadState](rest_api/docs/ReadState.md)
 - [SQLParameters](rest_api/docs/SQLParameters.md)
 - [SSOProvider](rest_api/docs/SSOProvider.md)
 - [Subarray](rest_api/docs/Subarray.md)
 - [SubarrayPartitioner](rest_api/docs/SubarrayPartitioner.md)
 - [SubarrayPartitionerCurrent](rest_api/docs/SubarrayPartitionerCurrent.md)
 - [SubarrayPartitionerState](rest_api/docs/SubarrayPartitionerState.md)
 - [SubarrayRanges](rest_api/docs/SubarrayRanges.md)
 - [Subscription](rest_api/docs/Subscription.md)
 - [Token](rest_api/docs/Token.md)
 - [TokenRequest](rest_api/docs/TokenRequest.md)
 - [UDF](rest_api/docs/UDF.md)
 - [UDFActions](rest_api/docs/UDFActions.md)
 - [UDFImage](rest_api/docs/UDFImage.md)
 - [UDFImageVersion](rest_api/docs/UDFImageVersion.md)
 - [UDFInfo](rest_api/docs/UDFInfo.md)
 - [UDFInfoUpdate](rest_api/docs/UDFInfoUpdate.md)
 - [UDFInfoVersion](rest_api/docs/UDFInfoVersion.md)
 - [UDFLanguage](rest_api/docs/UDFLanguage.md)
 - [UDFListingData](rest_api/docs/UDFListingData.md)
 - [UDFRanges](rest_api/docs/UDFRanges.md)
 - [UDFResultType](rest_api/docs/UDFResultType.md)
 - [UDFSharing](rest_api/docs/UDFSharing.md)
 - [UDFSubarray](rest_api/docs/UDFSubarray.md)
 - [UDFSubarrayRange](rest_api/docs/UDFSubarrayRange.md)
 - [UDFType](rest_api/docs/UDFType.md)
 - [User](rest_api/docs/User.md)
 - [Writer](rest_api/docs/Writer.md)


## Documentation For Authorization


## ApiKeyAuth

- **Type**: API key
- **API key parameter name**: X-TILEDB-REST-API-KEY
- **Location**: HTTP header


## BasicAuth

- **Type**: HTTP basic authentication


## OAuth2

- **Type**: OAuth
- **Flow**: accessCode
- **Authorization URL**: https://oauth2.tiledb.com/oauth2/authorize
- **Scopes**: 
 - **read**: Grants read access
 - **write**: Grants write access
 - **admin**: Grants read and write access to administrative information


## Author




